#ifndef ATM168_H_
#define ATM168_H_

//Hardware IO defs
typedef union port_b
{
	unsigned char value;
	struct 
	{
		unsigned char icp1:1;				//SONAR ICP pin
		unsigned char pan:1;				//sensor turret pan
		unsigned char tilt:1;				//sensor turret tilt
		unsigned char leftDir:1;			//left motor direction
		unsigned char rightDir:1;			//right motor direction
		unsigned char fireSense:1;			//fire detector
		unsigned char none:2;				//OSC1&2, not used
	};
	struct 
	{
		unsigned char b0:1;
		unsigned char b1:1;
		unsigned char b2:1;
		unsigned char b3:1;
		unsigned char b4:1;
		unsigned char b5:1;
		unsigned char b6:1;
		unsigned char b7:1;
	};
} port_b;
#define PORTBbits (*((volatile port_b *)(&PORTB)))
#define PINBbits (*((volatile port_b *)(&PINB)))

typedef union port_c
{
	unsigned char value;						//whole 8 bits
	struct
	{
		unsigned char b0:1;						//Generic bits
		unsigned char b1:1;
		unsigned char b2:1;
		unsigned char b3:1;
		unsigned char b4:1;
		unsigned char b5:1;
		unsigned char b6:1;
		unsigned char b7:1;		
	};
} port_c;
#define PORTCbits (*((volatile port_c *)(&PORTC)))
#define PINCbits (*((volatile port_c *)(&PINC)))

typedef union port_d
{
	unsigned char value;						//whole 8 bits
	struct 
	{
		unsigned char b0:1;						//Generic bits
		unsigned char b1:1;
		unsigned char b2:1;
		unsigned char b3:1;
		unsigned char b4:1;
		unsigned char b5:1;
		unsigned char b6:1;
		unsigned char b7:1;		
	};
} port_d;
#define PORTDbits (*((volatile port_d *)(&PORTD)))// Defines that are, for some reason, not in the correct pin location
#define PINDbits (*((volatile port_d *)(&PIND)))// Defines that are, for some reason, not in the correct pin location

//Configurations for hardware devices (timers/PWM/counters/etc.)
void initialize();
void waitms(int d);

#define LEFTMOTOR OCR0B				//left motor PWM
#define RIGHTMOTOR OCR0A			//right motor
#define M_ENABLE PORTDbits.b4		//motor enable line

//PWM sense 
#define L_NORMALPWM 0x10;			//When set this reverses the PWM sense
#define R_NORMALPWM 0x40;			//As above, but for OC0A
//Direction port I/O line
#define L_DIR PORTBbits.leftDir
#define R_DIR PORTBbits.rightDir
//Direction bit settings
#define FWD 0
#define REV 1
#define ON 1
#define OFF 0
//encoder inputs
#define PHASE1 PINDbits.b2		//Phase one pin
#define PHASE2 PINDbits.b3

void InitMotors(void);
void SetMotorSpeed(int speedL, int speedR);
void MotorsStop(void);
void MotorsGo(int leftM, int rightM);

#endif /*ATM168_H_*/
